@@ -1,10 +1,21 @@
 """Models for database"""
 from datetime import datetime
 
-from elixir import *
+from elixir import Field
+from elixir import Float
+from elixir import Entity
+from elixir import String
+from elixir import Integer
+from elixir import Boolean
+from elixir import DateTime
+from elixir import metadata
+from elixir import setup_all
+from elixir import create_all
+from elixir import using_options
 
 from veliberator.settings import DATABASE_URI, DATABASE_ECHO
 
+
 class StationInformation(Entity):
     """Station information entity model"""
     id = Field(Integer, primary_key=True)
@@ -12,9 +23,9 @@ class StationInformation(Entity):
     address = Field(String(100))
     postal_code = Field(String(100))
     city = Field(String(100))
-    
-    lat = Field(String(30))
-    lng = Field(String(30))
+
+    lat = Field(Float)
+    lng = Field(Float)
 
     opened = Field(Boolean)
     bonus = Field(Boolean)
