@@ -1,12 +1,11 @@
 """Station objects for veliberator"""
-from xml.dom.minidom import parse
-
 from veliberator.models import db_connection
 from veliberator.models import StationInformation
 from veliberator.status import StationStatus
 from veliberator.geofinder import StationGeoFinder
 from veliberator.settings import STATION_ALMOST_FULL
 from veliberator.settings import STATION_ALMOST_EMPTY
+from veliberator.settings import STATION_AROUND_RADIUS
 
 STATUS_OPEN = u'open'
 STATUS_CLOSE = u'close'
@@ -18,9 +17,11 @@ STATUS_ALMOST_FULL = u'almost-full'
 STATUS_ALMOST_EMPTY = u'almost-empty'
 STATUS_NO_SERVICE = u'no-service'
 
+
 class UnknowStation(Exception):
     pass
 
+
 class Station(object):
     """Station object,
     combinating informations and status"""
@@ -67,7 +68,7 @@ class Station(object):
     @property
     def stations_around(self):
         """Find the stations around"""
-        return self.finder.get_stations_around()
+        return self.finder.get_stations_around(STATION_AROUND_RADIUS)
 
     @property
     def state(self):
@@ -77,7 +78,7 @@ class Station(object):
 
         free = self.status.free
         available = self.status.available
-        total =  self.status.total
+        total = self.status.total
 
         if not available and not free:
             if not total:
@@ -99,5 +100,3 @@ class Station(object):
         if self.informations:
             return '<Station "%s" (%s)>' % (self.id, self.informations.address)
         return '<Station "%s">' % self.id
-
-
